import ajax from '../../util/ajax'
import api from '../../util/api'

export default {
  namespaced: true,
  state: {
    courseList: [],
    courseInfo: {},
  },
  mutations: {
    updateList (state, payload) {
      state.courseList = payload || []
    },
    updateInfo (state, payload) {
      state.courseInfo = payload || {}
    },
  },
  actions: {
    GetCourseList ({ commit }, payload) {
      ajax(api.course.list.url, {
        method: api.course.list.method,
        queryData: {
          ...payload,
        }
      }).then(res => {
        commit('updateList', res)
      })
    },
    GetCourseByID ({ commit }, { id }) {
      ajax(api.course.info.url, {
        method: api.course.info.method,
        urlData: {
          id: id,
        }
      }).then(res => {
        commit('updateInfo', res)
      })
    },
    AddCourse ({ commit }, payload) {
      ajax(api.course.add.url, {
        method: api.course.add.method,
        data: {
          ...payload
        }
      }).then(res => {
        commit('updateInfo', res)
      })
    },
    UpdateCourse ({ commit }, payload) {
      ajax(api.course.update.url, {
        method: api.course.update.method,
        data: {
          ...payload
        },
        urlData: {
          id: payload.GoodsId,
        }
      }).then(res => {
      })
    },
    DelCourse ({ commit }, { id, callback }) {
      ajax(api.course.delete.url, {
        method: api.course.delete.method,
        urlData: {
          id: id,
        }
      }).then(res => {
        if (callback) {
          callback()
        }
      })
    },
    Public ({ commit }, { id, callback }) {
      ajax(api.course.public.url, {
        method: api.course.public.method,
        urlData: {
          id: id,
        }
      }).then(res => {
        if (callback) {
          callback()
        }
      })
    },
    UnPublic ({ commit }, { id, callback }) {
      ajax(api.course.unpublic.url, {
        method: api.course.unpublic.method,
        urlData: {
          id: id,
        }
      }).then(res => {
        if (callback) {
          callback()
        }
      })
    },
    SetNull ({ commit }) {
      commit('updateInfo', {})
    },
    UpdateInfo ({ commit }, payload) {
      commit('updateInfo', payload)
    }
  }
}
